@@ -40,6 +40,7 @@ from Cython.Compiler.ExprNodes import DictComprehensionAppendNode
 from Cython.Compiler.ExprNodes import DictNode
 from Cython.Compiler.ExprNodes import FloatNode
 from Cython.Compiler.ExprNodes import FormattedValueNode
+from Cython.Compiler.ExprNodes import GeneratorExpressionNode
 from Cython.Compiler.ExprNodes import ImportNode
 from Cython.Compiler.ExprNodes import IndexNode
 from Cython.Compiler.ExprNodes import IntNode
@@ -651,12 +652,48 @@ def _traverse_file(  # noqa: PLR0915,PLR0913
                 ),
             )
 
-        if isinstance(node, ExprStatNode) and isinstance(node.expr, UnicodeNode):
+        if (
+            isinstance(node, ExprStatNode)
+            and isinstance(node.expr, UnicodeNode)
+            and isinstance(node_parent.parent, StatListNode)
+        ):
+            try:
+                idx = node_parent.parent.stats.index(node)
+            except ValueError:  # pragma: no cover
+                pass  # defensive check
+            else:
+                if not isinstance(
+                    node_parent.parent.stats[idx - 1], SingleAssignmentNode
+                ):
+                    violations.append(
+                        (
+                            node.pos[1],
+                            node.pos[2] + 1,
+                            "pointless string statement",
+                        ),
+                    )
+
+        if (
+            isinstance(node, SimpleCallNode)
+            and isinstance(node.function, NameNode)
+            and hasattr(node.function, "name")
+            and node.args
+            and len(node.args) == 1
+            and isinstance(node.args[0], (GeneratorExpressionNode, ComprehensionNode))
+            and (
+                node.function.name in {"list", "set"}
+                or (
+                    node.function.name == "dict"
+                    and isinstance(node.args[0].loop.target, TupleNode)
+                    and len(node.args[0].loop.target.args) == 2
+                )
+            )
+        ):
             violations.append(
                 (
                     node.pos[1],
                     node.pos[2] + 1,
-                    "pointless string statement",
+                    f"unnecessary {node.function.name} + generator (just use a {node.function.name} comprehension)",
                 ),
             )
 
